@@ -51,6 +51,14 @@ class Geo_common:
             which_sheet = project_name
         data = ParserXLS.fetch_row(excel, which_sheet, "SAMPLES")        # sample name 必须在第一列
         for line in data[1:]:
+            # 跳过空行
+            if_empty = True
+            for s in line:
+                if s.strip():
+                    if_empty = False
+            if if_empty:
+                continue
+
             for head in data[0][1:]:
                 tmp = line[data[0].index(head)]
                 if head in ["group","raw_file_r1","raw_file_r2"]:      # 这三个key允许多个值, 一致使用列表元素
@@ -116,7 +124,7 @@ class Geo_common:
         ############ singularity 挂载信息
         roots= []
         self.singularity_args = ''
-        for i in [pipe_dir , pro_dir] + [self.samples[sample]["raw_file_r1"][0] for sample in self.samples]:
+        for i in [pipe_dir , pro_dir , 'abc'] + [self.samples[sample]["raw_file_r1"][0] for sample in self.samples]:
             i = i.split("/")[1]
             roots.append(i)
         roots = set(roots)
